cd "H:\Crisis Bargaining Experiment\QJPS\"
use TingleyWang-QJPS.dta, clear

*IncentiveType=1 for High cost 2 for low cost

*overall descriptives of values in the experiment
tabout  one using "GenderBreakdown_51308.xls" if  IncentiveType==1, topf(title.txt) f(2) topstr("Experiment Descriptives by Experiment Type")  h1(nil)  ptotal(none)   cell(mean value sd value mean belief sd belief mean gamepay sd gamepay mean beliefpay sd beliefpay mean gender count gender) sum style(tab) replace
tabout  one using "GenderBreakdown_51308.xls" if  IncentiveType==2, f(2)   ptotal(none)  h1(nil) h2(nil) h3(nil)  cell(mean value sd value mean belief sd belief mean gamepay sd gamepay mean beliefpay sd beliefpay mean gender count gender) sum style(tab) append


*COMPARISON TO GUESSES FROM LOGISTIC DRAW
*GENERATE RANDOM DRAWS FROM OUR LOGIT TO SEE HOW MUCH ONE WOULD EARN FROM BELIEFS IF THEY GUESSED RANDOMLY
set seed 1234
gen u=uniform()
gen logistic_dist=-ln(1/u-1)

*CALCULATES THE EARNINGS FROM GUESSING OR NOT UPDATING AND GUESSING THE PRIOR
gen guess_beliefearn=.5-.1*( othervalue-logistic_dist)^2

gen BelPayDiffRealGss=beliefpay-guess_beliefearn

*Mean payoffs with Clustering by subject for se's
reg BelPayDiffRealGss  if  IncentiveType==1 , cl(subjectID)
reg BelPayDiffRealGss  if  IncentiveType==2 , cl(subjectID)




*BEST RESPONSE (in footnote)...merged data set uses best response according to pbe.
gen roundbelief=round(belief,.1)
sort position roundbelief
merge position roundbelief using "bestresponse_probF.dta", uniqusing _merge(MergeBestResponse) 

*calculates expected utility calculations. In low cost condition there is a prob that 1 will not fight
gen EUResist=(.5+value)*probabilityfight+(1- probabilityfight)*.5 if position==2 & value~=. & IncentiveType==2
replace EUResist=(.5+value) if position==2 & value~=. & IncentiveType==1
gen ShouldR=1 if EUResist>-.3 & position==2
replace ShouldR=0 if EUResist<=-.3 & position==2
gen MissClassEU=1 if ShouldR~=ResistPeriod1 & ShouldR~=. &  ResistPeriod1~=.
replace MissClassEU=0 if ShouldR==ResistPeriod1 & ShouldR~=. &  ResistPeriod1~=.
tab  MissClassEU IncentiveType, col

gen EUFight=.5+value if position==1 & value~=. 
gen ShouldF=1 if EUFight>-.3 & position==1 & IncentiveType==1
replace ShouldF=0 if EUFight<=-.3 & position==1 & IncentiveType==1
replace ShouldF=1 if EUFight>-.1 & position==1 & IncentiveType==2
replace ShouldF=0 if EUFight<=-.1 & position==1 & IncentiveType==2
gen MissClassEU_Fight=1 if ShouldF~=FightPeriod1 & ShouldF~=. &  FightPeriod1~=.
replace MissClassEU_Fight=0 if ShouldF==FightPeriod1 & ShouldF~=. &  FightPeriod1~=.
tab  MissClassEU_Fight IncentiveType, col



*Testing the Belief Hypotheses
*Following entry
*calculate means
ttest belief if (PartnerRnd1Dec==3|PartnerRnd1Dec==6|PartnerRnd1Dec==7) & position==2  ,by( IncentiveType )
*calculate significance using clustering
reg belief IncentiveType if (PartnerRnd1Dec==3|PartnerRnd1Dec==6|PartnerRnd1Dec==7) & position==2  , cluster(subjectID)

*following Resist
ttest belief if PartnerRnd1Dec==5 & position==1  ,by( IncentiveType )
reg belief IncentiveType if PartnerRnd1Dec==5 & position==1  , cluster(subjectID)

*following Not Resist
ttest belief if PartnerRnd1Dec==4 & position==1  ,by( IncentiveType )
reg belief IncentiveType if PartnerRnd1Dec==4 & position==1  , cluster(subjectID)



*RATIONAL EXPECTATIONS
gen OtherEnter=(moveIDother==3|moveIDother==6|moveIDother==7 & position==2)
replace OtherEnter=. if position==1
gen OtherResist=(moveIDother==5 & position==1)
replace OtherResist=. if position==2
replace OtherResist=. if moveIDother==2

foreach var of newlist Enter Resist {
gen OtherNot`var'=1 if Other`var'==0
replace OtherNot`var'=0 if Other`var'==1
}


gen BeliefDiff=belief-othervalue

reg BeliefDiff OtherNotEnter if IncentiveType==1, nocons robust cluster(subjectID)
reg BeliefDiff OtherNotEnter if IncentiveType==2, nocons robust cluster(subjectID)
reg BeliefDiff OtherEnter if IncentiveType==2, nocons robust cluster(subjectID)
reg BeliefDiff OtherEnter if IncentiveType==1, nocons robust cluster(subjectID)


reg BeliefDiff OtherResist if IncentiveType==2, nocons robust cluster(subjectID)
reg BeliefDiff OtherResist if IncentiveType==1, nocons robust cluster(subjectID)
reg BeliefDiff OtherNotResist if IncentiveType==2, nocons robust cluster(subjectID)
reg BeliefDiff OtherNotResist if IncentiveType==1, nocons robust cluster(subjectID)


*CONSERVATIVE UPDATING TABLE
preserve
forval j=1/2 {
foreach move of varlist OtherEnter OtherResist  OtherNotEnter OtherNotResist {
foreach var of varlist belief othervalue {
capture reg `var' `move' if IncentiveType==`j', nocons robust cluster(subjectID)
capture mat b=e(b)
capture mat v=e(V)
capture local b=b[1,1]
capture local v=v[1,1]
gen b`var'`j'`move'=b[1,1]
gen v`var'`j'`move'=sqrt(v[1,1])
*gen r`var'`j'`move'=b`var'`j'`move'/v`var'`j'`move'
}
}
}

keep bbelief* bothervalue* vbelief* vothervalue*
keep if _n==1
gen id=1
reshape long bbelief1 bothervalue1 vbelief1 vothervalue1 bbelief2 bothervalue2 vbelief2 vothervalue2 , i(id) j(choice) str
saveold RE-Table.dta, replace
restore


*Supplementary Materials
*Entry Strategies
prtest EnterPeriod1 , by(IncentiveType)
reg EnterPeriod1 IncentiveType , cl(subject)


*Resist Strategies
ttest value if ResistPeriod1==1 & position==2  ,by(IncentiveType) unequal
reg value IncentiveType if ResistPeriod1==1 & position==2  , cluster(subject)
prtest ResistPeriod1 , by(IncentiveType)
reg ResistPeriod1 IncentiveType , cl(subject)

*Fight Stragies 
prtest FightPeriod1 , by(IncentiveType)
reg FightPeriod1 IncentiveType , cl(subject)
reg value IncentiveType if FightPeriod1==1, cl(subject)


